@@ -1,7 +1,3 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import
-
 # Threedigrid version number is automatic updated with zest.releaser
 # the version number in setup.py is updated using the find_version()
-__version__ = '1.1.11'
+__version__ = "1.2.0"
