@@ -1,5 +1,4 @@
 # (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
-# -*- coding: utf-8 -*-
 """
 Exporters
 ---------
@@ -20,25 +19,20 @@ At this moment there is one exporter for breach data, called
     >>> {u'ESRI Shapefile', u'GPKG'}
 
 """
-from __future__ import unicode_literals
-from __future__ import print_function
 
-from __future__ import absolute_import
-import os
 import logging
+import os
 from collections import OrderedDict
-import six
-from six.moves import range
 
 try:
     from osgeo import ogr
 except ImportError:
     ogr = None
 
-from threedigrid.numpy_utils import reshape_flat_array
-from threedigrid.geo_utils import get_spatial_reference
-from threedigrid.admin.utils import KCUDescriptor
 from threedigrid.admin import exporter_constants as const
+from threedigrid.admin.utils import KCUDescriptor
+from threedigrid.geo_utils import get_spatial_reference
+from threedigrid.numpy_utils import reshape_flat_array
 from threedigrid.orm.base.exporters import BaseOgrExporter
 
 logger = logging.getLogger(__name__)
@@ -49,6 +43,7 @@ class BreachesOgrExporter(BaseOgrExporter):
     ogr exporter for breaches. See ``<instance>.supported_drivers`` to
     get a list of supported drivers
     """
+
     def __init__(self, breaches):
         self._breaches = breaches
         self.supported_drivers = {
@@ -73,44 +68,37 @@ class BreachesOgrExporter(BaseOgrExporter):
         sr = get_spatial_reference(target_epsg_code)
         self.del_datasource(file_name)
         data_source = self.driver.CreateDataSource(file_name)
-        layer = data_source.CreateLayer(
-            str(os.path.basename(file_name)),
-            sr,
-            geomtype
+        layer = data_source.CreateLayer(str(os.path.basename(file_name)), sr, geomtype)
+        fields = OrderedDict(
+            [
+                ("link_id", "int"),
+                ("kcu", "int"),
+                ("kcu_descr", "str"),
+                ("cont_pk", "int"),
+            ]
         )
-        fields = OrderedDict([
-            ('link_id', 'int'),
-            ('kcu', 'int'),
-            ('kcu_descr', 'str'),
-            ('cont_pk', 'int'),
-        ])
-        for field_name, field_type in six.iteritems(fields):
+        for field_name, field_type in fields.items():
             layer.CreateField(
-                ogr.FieldDefn(
-                    str(field_name),
-                    const.OGR_FIELD_TYPE_MAP[field_type]
-                )
+                ogr.FieldDefn(str(field_name), const.OGR_FIELD_TYPE_MAP[field_type])
             )
         _definition = layer.GetLayerDefn()
-        points = reshape_flat_array(selection['coordinates']).T
+        points = reshape_flat_array(selection["coordinates"]).T
 
-        for i in range(selection['id'].size):
+        for i in range(selection["id"].size):
             if selection["id"][i] == 0:
                 continue  # skip the dummy element
             feature = ogr.Feature(_definition)
             point = ogr.Geometry(ogr.wkbPoint)
             point.AddPoint(points[i][0], points[i][1])
             feature.SetGeometry(point)
-            self.set_field(feature, "link_id", "int", selection['levl'][i])
-            kcu = selection['kcu'][i]
+            self.set_field(feature, "link_id", "int", selection["levl"][i])
+            kcu = selection["kcu"][i]
             self.set_field(feature, "kcu", "int", kcu)
-            kcu_descr = ''
+            kcu_descr = ""
             try:
                 kcu_descr = kcu_dict[kcu]
             except KeyError:
                 pass
             self.set_field(feature, "kcu_descr", "str", kcu_descr)
-            self.set_field(
-                feature, "cont_pk", "int", selection['content_pk'][i]
-            )
+            self.set_field(feature, "cont_pk", "int", selection["content_pk"][i])
             layer.CreateFeature(feature)
