@@ -8,13 +8,9 @@ threedicore with shape, width and height information.
 
 """
 
-from __future__ import unicode_literals
-from __future__ import print_function
 
-from __future__ import absolute_import
-
-from threedigrid.orm.models import Model
 from threedigrid.orm.fields import ArrayField
+from threedigrid.orm.models import Model
 
 
 class CrossSections(Model):
