@@ -1,16 +1,13 @@
 # (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-from __future__ import print_function
 
-from __future__ import absolute_import
 import logging
-import numpy as np
-from threedigrid.orm.base.datasource import DataSource
 from collections import OrderedDict
-from h5py._hl.dataset import Dataset
-from threedigrid.admin.h5py_swmr import H5SwmrFile
 
+import numpy as np
+from h5py._hl.dataset import Dataset
+
+from threedigrid.admin.h5py_swmr import H5SwmrFile
+from threedigrid.orm.base.datasource import DataSource
 
 logger = logging.getLogger(__name__)
 
@@ -20,39 +17,38 @@ class H5pyGroup(DataSource):
     Datasource wrapper for h5py groups,
     adding meta data to all groups.
     """
+
     _group_name = None
     _h5py_file = None
 
     def get_filtered_field_value(
-            self, model, field_name, ts_filter=None, lookup_index=None,
-            subset_index=None):
+        self, model, field_name, ts_filter=None, lookup_index=None, subset_index=None
+    ):
 
         kwargs = {}
         if ts_filter is None:
-            if hasattr(model, 'get_timeseries_mask_filter'):
+            if hasattr(model, "get_timeseries_mask_filter"):
                 timeseries_filter = model.get_timeseries_mask_filter()
                 ts_filter = timeseries_filter
                 if isinstance(timeseries_filter, dict):
                     ts_filter = timeseries_filter.get(field_name)
 
         if ts_filter is not None:
-            kwargs.update(
-                {'timeseries_filter': ts_filter}
-            )
+            kwargs.update({"timeseries_filter": ts_filter})
 
         if lookup_index is None:
-            if model._mixin and hasattr(model.Meta, 'lookup_fields'):
+            if model._mixin and hasattr(model.Meta, "lookup_fields"):
                 lookup_index = model._meta._get_lookup_index()
 
         if lookup_index is not None:
-            kwargs.update({'lookup_index': lookup_index})
+            kwargs.update({"lookup_index": lookup_index})
 
         if subset_index is None:
-            if model._mixin and hasattr(model.Meta, 'subset_fields'):
+            if model._mixin and hasattr(model.Meta, "subset_fields"):
                 subset_index = model._get_subset_idx(field_name)
 
         if subset_index is not None:
-            kwargs.update({'subset_index': model._get_subset_idx(field_name)})
+            kwargs.update({"subset_index": model._get_subset_idx(field_name)})
 
         value = model.get_field_value(field_name, **kwargs)
 
@@ -73,8 +69,7 @@ class H5pyGroup(DataSource):
         if value is None or value.size == 0:
             return np.array([])
 
-        _filter = [slice(None)] * (
-            len(value.shape) - 1) + [model.boolean_mask_filter]
+        _filter = [slice(None)] * (len(value.shape) - 1) + [model.boolean_mask_filter]
 
         # By default load all data from H5,
         # this is WAY much faster
@@ -88,7 +83,8 @@ class H5pyGroup(DataSource):
         # there are coordinatefields in the selection
         if model.reproject_to_epsg and model._is_coords(field_name):
             value = model._do_reproject_value(
-                    value, field_name, model.reproject_to_epsg)
+                value, field_name, model.reproject_to_epsg
+            )
 
         if isinstance(value, np.ma.core.MaskedArray):
             # Always return the data of a masked array
@@ -107,13 +103,13 @@ class H5pyGroup(DataSource):
         lookup_index = None
         has_subsets = False
 
-        if hasattr(model, 'get_timeseries_mask_filter'):
+        if hasattr(model, "get_timeseries_mask_filter"):
             timeseries_filter = model.get_timeseries_mask_filter()
 
-        if model._mixin and hasattr(model.Meta, 'lookup_fields'):
+        if model._mixin and hasattr(model.Meta, "lookup_fields"):
             lookup_index = model._meta._get_lookup_index()
 
-        if model._mixin and hasattr(model.Meta, 'subset_fields'):
+        if model._mixin and hasattr(model.Meta, "subset_fields"):
             has_subsets = True
 
         for n in model._field_names:
@@ -129,16 +125,19 @@ class H5pyGroup(DataSource):
                     subset_index = None
 
                 selection[n] = model.get_filtered_field_value(
-                    n, ts_filter=ts_filter, lookup_index=lookup_index,
-                    subset_index=subset_index)
+                    n,
+                    ts_filter=ts_filter,
+                    lookup_index=lookup_index,
+                    subset_index=subset_index,
+                )
 
         # Inject timestamps automatically
-        if hasattr(model, 'get_timestamps'):
-            if getattr(model, 'is_aggregate', False):
+        if hasattr(model, "get_timestamps"):
+            if getattr(model, "is_aggregate", False):
                 # Output one array of timestamps per field
                 for n in model._field_names:
                     if not model.only_fields or n in model.only_fields:
-                        field_name = '%s_%s' % (n, 'timestamps')
+                        field_name = "{}_{}".format(n, "timestamps")
                         try:
                             selection[field_name] = model.get_timestamps(n)
                         except (AttributeError, TypeError):
@@ -146,8 +145,7 @@ class H5pyGroup(DataSource):
 
             else:
                 # Output one array with timestamps for all fields
-                selection['timestamps'] = model.get_timestamps(
-                    timeseries_filter)
+                selection["timestamps"] = model.get_timestamps(timeseries_filter)
 
         return selection
 
@@ -157,8 +155,9 @@ class H5pyGroup(DataSource):
 
         if group_name not in list(h5py_file.keys()) and not required:
             logger.info(
-                '[*] {0} not found in file {1}, not required...'.format(
-                    group_name, h5py_file)
+                "[*] {} not found in file {}, not required...".format(
+                    group_name, h5py_file
+                )
             )
             return
 
@@ -167,9 +166,8 @@ class H5pyGroup(DataSource):
         except TypeError:
             self._source = h5py_file[group_name]
 
-        self.meta = dict(
-            [(y, [x[()]]) for y, x in self._h5py_file.get('meta').items()])
-        self.meta['trash'] = [1]
+        self.meta = {y: [x[()]] for y, x in self._h5py_file.get("meta").items()}
+        self.meta["trash"] = [1]
 
     def set(self, name, values):
         if name in self._source:
@@ -182,7 +180,7 @@ class H5pyGroup(DataSource):
     def getattr(self, name):
         attr = self._h5py_file.attrs[name]
         if isinstance(attr, bytes):
-            attr = attr.decode('utf-8')
+            attr = attr.decode("utf-8")
         return attr
 
     def keys(self):
@@ -195,28 +193,25 @@ class H5pyGroup(DataSource):
         Check if the any of the sources can be found in
         the file
         """
-        return any(x in list(self.keys())
-                   for x in sources)
+        return any(x in list(self.keys()) for x in sources)
 
 
 class H5pyResultGroup(H5pyGroup):
-    def __init__(self, h5py_file, group_name, netcdf_file,
-                 meta=None, required=False):
-        super(H5pyResultGroup, self).__init__(
-            h5py_file, group_name, meta, required)
+    def __init__(self, h5py_file, group_name, netcdf_file, meta=None, required=False):
+        super().__init__(h5py_file, group_name, meta, required)
         self.netcdf_file = netcdf_file
 
         if isinstance(netcdf_file, H5SwmrFile):
             self.swmr_mode = True
 
     def keys(self):
-        keys = list(super(H5pyResultGroup, self).keys())
+        keys = list(super().keys())
         keys += list(self.netcdf_file.keys())
         return list(set(keys))
 
     def get(self, name):
         # meta is special
-        if name == 'meta':
+        if name == "meta":
             return self.meta
 
         if name in self._source:
@@ -230,16 +225,16 @@ class H5pyResultGroup(H5pyGroup):
     def attr(self, var_name, attr_name):
         v = self.get(var_name)
         if v is None:
-            return ''
+            return ""
         try:
             return v.attrs.get(attr_name)
         except AttributeError:
             pass
-        return ''
+        return ""
 
     def __getitem__(self, name):
         # meta is special
-        if name == 'meta':
+        if name == "meta":
             return self.meta
 
         if name in self._source:
