@@ -1,12 +1,7 @@
 # (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-from __future__ import print_function
 
-from __future__ import absolute_import
+from threedigrid.orm.fields import ArrayField, LineArrayField, PointArrayField
 from threedigrid.orm.models import Model
-from threedigrid.orm.fields import (
-    ArrayField, LineArrayField, PointArrayField)
 
 
 class Pumps(Model):
