@@ -1,11 +1,8 @@
-from __future__ import absolute_import
-from abc import ABCMeta
-from abc import abstractmethod
-import os
 import logging
-import six
-from threedigrid.admin.constants import TYPE_FUNC_MAP, FID_FIELDS
+import os
+from abc import ABCMeta, abstractmethod
 
+from threedigrid.admin.constants import FID_FIELDS, TYPE_FUNC_MAP
 
 try:
     from osgeo import ogr
@@ -17,15 +14,14 @@ try:
 except ImportError:
     gdal = None
 
+from threedigrid.geo_utils import raise_import_exception
 from threedigrid.orm import constants
 from threedigrid.orm.base.exceptions import DriverNotSupportedError
-from threedigrid.geo_utils import raise_import_exception
 
 logger = logging.getLogger(__name__)
 
 
-class BaseExporterObject(six.with_metaclass(ABCMeta)):
-
+class BaseExporterObject(metaclass=ABCMeta):
     @abstractmethod
     def save(self):
         """
@@ -40,9 +36,9 @@ class BaseOgrExporter(BaseExporterObject):
 
     def __init__(self):
         if ogr is None:
-            raise_import_exception('ogr')
+            raise_import_exception("ogr")
         if gdal is None:
-            raise_import_exception('gdal')
+            raise_import_exception("gdal")
 
     @staticmethod
     def set_field(feature, field_name, field_type, raw_value):
@@ -60,15 +56,20 @@ class BaseOgrExporter(BaseExporterObject):
         if field_name in FID_FIELDS and value is not None:
             feature.SetFID(value)
 
-    def set_driver(self, driver_name='', extension=''):
-        assert any((driver_name, extension)), \
-            'either driver_name or extension must be given'
+    def set_driver(self, driver_name="", extension=""):
+        assert any(
+            (driver_name, extension)
+        ), "either driver_name or extension must be given"
         if not driver_name:
             driver_name = constants.EXTENSION_TO_DRIVER_MAP[extension.lower()]
-        if all([driver_name == constants.GEO_PACKAGE_DRIVER_NAME,
-                int(gdal.VersionInfo('VERSION_NUM')) < 2000000]):
-            logger.error('Requires GDAL >= 2.0(dev)')
-            raise DriverNotSupportedError('Requires GDAL >= 2.0(dev)')
+        if all(
+            [
+                driver_name == constants.GEO_PACKAGE_DRIVER_NAME,
+                int(gdal.VersionInfo("VERSION_NUM")) < 2000000,
+            ]
+        ):
+            logger.error("Requires GDAL >= 2.0(dev)")
+            raise DriverNotSupportedError("Requires GDAL >= 2.0(dev)")
         self.driver = ogr.GetDriverByName(str(driver_name))
 
     @property
@@ -79,5 +80,5 @@ class BaseOgrExporter(BaseExporterObject):
     def del_datasource(self, file_name):
         if not os.path.exists(file_name):
             return
-        logger.info('[*] Replacing %s ...', file_name)
+        logger.info("[*] Replacing %s ...", file_name)
         self.driver.DeleteDataSource(str(file_name))
